==> haskell-strict-list-0.1.7.6-101-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-strict-list.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 strict-list
version:              0.1.7.6
visibility:           public
id:                   strict-list-0.1.7.6-E6f5OqHUPYwHapSHNfAn4X
key:                  strict-list-0.1.7.6-E6f5OqHUPYwHapSHNfAn4X
license:              MIT
copyright:            (c) 2019, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/strict-list
synopsis:             Strict linked list
description:
    Implementation of strict linked list with care taken about stack.

category:             Data
abi:                  76b2df5ea964c509df3dd6241b93cc0b
exposed:              True
exposed-modules:      StrictList
hidden-modules:       StrictList.Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/strict-list-0.1.7.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/strict-list-0.1.7.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/strict-list-0.1.7.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-strict-list
hs-libraries:         HSstrict-list-0.1.7.6-E6f5OqHUPYwHapSHNfAn4X
depends:
    base-4.17.2.1 deepseq-1.4.8.0
    hashable-1.4.4.0-HF0gObldLcB4LirfpxeD3R
    semigroupoids-6.0.1-6I5b3GpOwhwAglmgd4w9RR

haddock-interfaces:   /usr/share/doc/haskell-strict-list/html/strict-list.haddock
haddock-html:         /usr/share/doc/haskell-strict-list/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-strict-list-0.1.7.6-122-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-strict-list.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 strict-list
version:              0.1.7.6
visibility:           public
id:                   strict-list-0.1.7.6-Gp4P2fAFLd95io9mTvhaEq
key:                  strict-list-0.1.7.6-Gp4P2fAFLd95io9mTvhaEq
license:              MIT
copyright:            (c) 2019, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/strict-list
synopsis:             Strict linked list
description:
    Implementation of strict linked list with care taken about stack.

category:             Data
abi:                  7bcc42391c1f808f2a84a24da4f22816
exposed:              True
exposed-modules:      StrictList
hidden-modules:       StrictList.Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/strict-list-0.1.7.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/strict-list-0.1.7.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/strict-list-0.1.7.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-strict-list
hs-libraries:         HSstrict-list-0.1.7.6-Gp4P2fAFLd95io9mTvhaEq
depends:
    base-4.17.2.1 deepseq-1.4.8.0
    hashable-1.4.7.0-KrA5CwhmktQ6Qu5a4JCqq7
    semigroupoids-6.0.1-Bxz0f1JNfGSLvZg0Ig0I9J

haddock-interfaces:   /usr/share/doc/haskell-strict-list/html/strict-list.haddock
haddock-html:         /usr/share/doc/haskell-strict-list/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
